@@ -8,79 +8,65 @@
 """Exported globals for webdataset library."""
 
 from . import tenbin
-from .fluid import Dataset
-from .dataset import (
-    WebDataset,
-    WebLoader,
-)
-from .pipeline import (
-    DataPipeline,
-    stage,
-)
-from .composable import (
-    Composable,
-    Shorthands,
-    Processor,
-)
-from .shardlists import (
-    SimpleShardList,
-    PytorchShardList,
-    ResampledShards,
-    split_by_node,
-    split_by_worker,
-    non_empty,
-    resampled,
-)
-from .extradatasets import (
-    MockDataset
-)
-from .tariterators import (
-    tarfile_samples,
-    tarfile_to_samples,
-)
-from .handlers import (
-    reraise_exception,
-    ignore_and_continue,
-    warn_and_continue,
-    ignore_and_stop,
-    warn_and_stop,
-)
-from .writer import ShardWriter, TarWriter, torch_dumps, numpy_dumps
 from .autodecode import (
     Continue,
-    handle_extension,
-    torch_loads,
-    imagehandler,
-    torch_video,
-    torch_audio,
     Decoder,
     gzfilter,
+    handle_extension,
+    imagehandler,
+    torch_audio,
+    torch_loads,
+    torch_video,
 )
-from .tariterators import (
-    url_opener,
-    tar_file_iterator,
-    tar_file_expander,
-    group_by_keys,
-)
-from .iterators import (
-    transform_with,
-    getfirst,
+from .cache import (
+    cached_tarfile_samples,
+    cached_tarfile_to_samples,
+    lru_cleanup,
+    pipe_cleaner,
 )
+from .cborsiterators import cbors2_to_samples, cbors_to_samples
+from .compat import WebDataset, WebLoader, FluidWrapper
+from .extradatasets import MockDataset, with_epoch, with_length
 from .filters import (
-    Curried,
-    info,
-    shuffle,
-    select,
-    decode,
-    map,
-    rename,
     associate,
-    map_dict,
-    to_tuple,
-    map_tuple,
     batched,
-    unbatched,
+    decode,
+    detshuffle,
+    getfirst,
+    info,
+    map,
+    map_dict,
+    map_tuple,
+    pipelinefilter,
+    rename,
+    rsample,
+    select,
+    shuffle,
     slice,
+    to_tuple,
+    transform_with,
+    unbatched,
 )
-from .dbcache import DBCache
-from .dsspecs import RoundRobin
+from .handlers import (
+    ignore_and_continue,
+    ignore_and_stop,
+    reraise_exception,
+    warn_and_continue,
+    warn_and_stop,
+)
+from .pipeline import DataPipeline
+from .shardlists import (
+    MultiShardSample,
+    ResampledShards,
+    SimpleShardList,
+    non_empty,
+    resampled,
+    shardspec,
+    single_node_only,
+    split_by_node,
+    split_by_worker,
+)
+from .tariterators import tarfile_samples, tarfile_to_samples
+from .utils import PipelineStage, repeatedly
+from .writer import ShardWriter, TarWriter, numpy_dumps, torch_dumps
+from .mix import RandomMix, RoundRobin
