@@ -6,11 +6,10 @@
 
 """A simple command line program to benchmark I/O speeds."""
 
-import argparse
-import time
+import argparse, time
 from collections import Counter
 
-from . import dataset
+from . import SimpleShardList, pipeline
 
 
 class TotalSize:
@@ -39,10 +38,10 @@ def main(args):
     for shard in args.shards:
         print("===", shard)
         totals = TotalSize()
-        ds = dataset.Dataset(shard)
-        ds.map(totals)
+        ds = pipeline.DataPipeline(SimpleShardList(shard))
+        ds = ds.then(filters.map(total))
         if args.decode != "":
-            ds = ds.decode(*eval("(" + args.decode + ",)"))
+            ds = ds.then(filters.decode(*eval("(" + args.decode + ",)")))
         keys = set()
         skeys = Counter()
         delta = None
